import {
  ParentBodyPathProvider_default
} from "./chunk-GLDVX3MD.mjs";
import {
  useParentBodyPath
} from "./chunk-SBY46IGC.mjs";
import {
  debugRef
} from "./chunk-BBDMJ3VH.mjs";

// src/components/Smart/index.tsx
import React64, { forwardRef as forwardRef63 } from "react";
import useMergedRef63 from "@react-hook/merged-ref";

// src/components/Code/index.tsx
import React, { forwardRef } from "react";
import useMergedRef from "@react-hook/merged-ref";
var Code = forwardRef(
  (props, forwardedRef) => {
    const { children, scopePath, debug } = props;
    const mergedRef = useMergedRef(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React.createElement(Smart_default, { code: children, scopePath, ref: mergedRef });
  }
);
Code.defaultProps = {
  debug: false
};
var Code_default = Code;

// src/components/BlockStatement/index.tsx
import React2, { forwardRef as forwardRef2 } from "react";
import useMergedRef2 from "@react-hook/merged-ref";
var BlockStatement = forwardRef2(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef2(forwardedRef, debugRef(debug));
    const code = "{}";
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React2.createElement(Code_default, null, children);
      }
      return children;
    }
    return /* @__PURE__ */ React2.createElement(Smart_default, { code, ref: mergedRef }, /* @__PURE__ */ React2.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren()));
  }
);
BlockStatement.defaultProps = { debug: false };
var BlockStatement_default = BlockStatement;

// src/components/Identifier/index.tsx
import React5, { forwardRef as forwardRef5 } from "react";
import useMergedRef5 from "@react-hook/merged-ref";

// src/components/types/TypeAnnotation/index.tsx
import React4, { forwardRef as forwardRef4 } from "react";
import useMergedRef4 from "@react-hook/merged-ref";

// src/components/types/TypeReference/index.tsx
import React3, { forwardRef as forwardRef3 } from "react";
import useMergedRef3 from "@react-hook/merged-ref";
var TypeReference = forwardRef3(
  (props, forwardedRef) => {
    const { children, name, debug } = props;
    const mergedRef = useMergedRef3(forwardedRef, debugRef(debug));
    const code = `const c: ${name} = 0`;
    return /* @__PURE__ */ React3.createElement(
      Smart_default,
      {
        bodyPath: "typeParameters",
        code,
        ref: mergedRef,
        scopePath: "declarations.0.id.typeAnnotation.typeAnnotation"
      },
      /* @__PURE__ */ React3.createElement(ParentBodyPathProvider_default, { value: void 0 }, children)
    );
  }
);
TypeReference.defaultProps = { debug: false };
var TypeReference_default = TypeReference;

// src/components/types/TypeAnnotation/index.tsx
var TypeAnnotation = forwardRef4(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef4(forwardedRef, debugRef(debug));
    const code = "const c: any = 0";
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React4.createElement(TypeReference_default, { name: children });
      }
      return children;
    }
    return /* @__PURE__ */ React4.createElement(
      Smart_default,
      {
        bodyPath: "typeAnnotation",
        code,
        deletePaths: "typeAnnotation",
        ref: mergedRef,
        scopePath: "declarations.0.id.typeAnnotation"
      },
      /* @__PURE__ */ React4.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren())
    );
  }
);
TypeAnnotation.defaultProps = { debug: false };
var TypeAnnotation_default = TypeAnnotation;

// src/components/Identifier/index.tsx
var Identifier = forwardRef5(
  (props, forwardedRef) => {
    const { children, debug, typeAnnotation } = props;
    const mergedRef = useMergedRef5(forwardedRef, debugRef(debug));
    const code = `var ${children}${typeAnnotation ? ": T" : ""}`;
    function renderTypeAnnotation() {
      if (!typeAnnotation)
        return null;
      return /* @__PURE__ */ React5.createElement(ParentBodyPathProvider_default, { value: "typeAnnotation" }, typeof typeAnnotation === "string" ? /* @__PURE__ */ React5.createElement(TypeAnnotation_default, null, typeAnnotation) : typeAnnotation, ";");
    }
    return /* @__PURE__ */ React5.createElement(Smart_default, { scopePath: "declarations.0.id", code, ref: mergedRef }, /* @__PURE__ */ React5.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderTypeAnnotation(), children));
  }
);
Identifier.defaultProps = { debug: false };
var Identifier_default = Identifier;

// src/components/classes/ClassDeclaration/index.tsx
import React7, { forwardRef as forwardRef7 } from "react";

// src/components/types/TypeParameterDeclaration/index.tsx
import React6, { forwardRef as forwardRef6 } from "react";
import useMergedRef6 from "@react-hook/merged-ref";
var TypeParameterDeclaration = forwardRef6((props, forwardedRef) => {
  const { children, debug } = props;
  const mergedRef = useMergedRef6(forwardedRef, debugRef(debug));
  const code = "class C<T> {}";
  function renderChildren() {
    if (typeof children === "string") {
      return /* @__PURE__ */ React6.createElement(TypeReference_default, { name: children });
    }
    return children;
  }
  return /* @__PURE__ */ React6.createElement(
    Smart_default,
    {
      bodyPath: "params",
      code,
      deletePaths: "params.0",
      ref: mergedRef,
      scopePath: "typeParameters"
    },
    /* @__PURE__ */ React6.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren())
  );
});
TypeParameterDeclaration.defaultProps = { debug: false };
var TypeParameterDeclaration_default = TypeParameterDeclaration;

// src/components/classes/ClassDeclaration/index.tsx
import useMergedRef7 from "@react-hook/merged-ref";
var ClassDeclaration = forwardRef7(
  (props, forwardedRef) => {
    const {
      children,
      debug,
      name,
      superClass,
      superTypeParameters,
      typeParameters
    } = props;
    const mergedRef = useMergedRef7(forwardedRef, debugRef(debug));
    const code = `class ${name} ${props.implements ? "implements b" : ""} {}`;
    function renderImplements() {
      if (!props.implements)
        return;
      return /* @__PURE__ */ React7.createElement(ParentBodyPathProvider_default, { value: "implements" }, props.implements);
    }
    function renderSuperClass() {
      return /* @__PURE__ */ React7.createElement(ParentBodyPathProvider_default, { value: "superClass" }, typeof superClass === "string" ? /* @__PURE__ */ React7.createElement(Identifier_default, null, superClass) : superClass);
    }
    function renderTypeParameter(typeParameter, index) {
      if (typeof typeParameter === "string") {
        return /* @__PURE__ */ React7.createElement(TypeReference_default, { key: index, name: typeParameter });
      } else if (React7.isValidElement(typeParameter)) {
        return React7.cloneElement(typeParameter, { key: index });
      }
      return null;
    }
    function renderTypeParameters() {
      if (!typeParameters)
        return null;
      return /* @__PURE__ */ React7.createElement(ParentBodyPathProvider_default, { value: "typeParameters" }, /* @__PURE__ */ React7.createElement(TypeParameterDeclaration_default, null, Array.isArray(typeParameters) ? typeParameters.map(
        (typeParameter, index) => renderTypeParameter(typeParameter, index)
      ) : renderTypeParameter(typeParameters, 0)));
    }
    function renderSuperTypeParameters() {
      if (!superTypeParameters)
        return null;
      return /* @__PURE__ */ React7.createElement(ParentBodyPathProvider_default, { value: "superTypeParameters" }, /* @__PURE__ */ React7.createElement(TypeParameterDeclaration_default, null, Array.isArray(superTypeParameters) ? superTypeParameters.map(
        (typeParameter, index) => renderTypeParameter(typeParameter, index)
      ) : renderTypeParameter(superTypeParameters, 0)));
    }
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React7.createElement(Code_default, null, children);
      }
      return children;
    }
    return /* @__PURE__ */ React7.createElement(Smart_default, { code, deletePaths: "implements.0", ref: mergedRef }, /* @__PURE__ */ React7.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderSuperClass(), renderSuperTypeParameters(), renderTypeParameters(), renderImplements(), /* @__PURE__ */ React7.createElement(BlockStatement_default, null, renderChildren())));
  }
);
ClassDeclaration.defaultProps = {
  debug: false
};
var ClassDeclaration_default = ClassDeclaration;

// src/components/classes/Class/index.tsx
import React8, { forwardRef as forwardRef8 } from "react";
import useMergedRef8 from "@react-hook/merged-ref";
var Class = forwardRef8(
  (props, forwardedRef) => {
    const clonedProps = { ...props };
    delete clonedProps.debug;
    delete clonedProps.extends;
    delete clonedProps.extendsTypeParameters;
    delete clonedProps.name;
    const { debug, extendsTypeParameters, name } = props;
    const mergedRef = useMergedRef8(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React8.createElement(
      ClassDeclaration_default,
      {
        ...clonedProps,
        name,
        ref: mergedRef,
        superClass: props.extends,
        superTypeParameters: extendsTypeParameters
      }
    );
  }
);
Class.defaultProps = {
  debug: false
};
var Class_default = Class;

// src/components/classes/ClassMethod/index.tsx
import React9, { forwardRef as forwardRef9 } from "react";
import useMergedRef9 from "@react-hook/merged-ref";
var ClassMethod = forwardRef9(
  (props, forwardedRef) => {
    const { accessibility, children, name, debug, returnType, params } = props;
    const mergedRef = useMergedRef9(forwardedRef, debugRef(debug));
    const code = `class C { ${accessibility ? `${accessibility} ` : ""}${props.static ? "static " : ""}${name}()${returnType ? ": T" : ""} {} }`;
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React9.createElement(Code_default, null, children);
      }
      return children;
    }
    function renderReturnType() {
      if (!returnType)
        return null;
      return /* @__PURE__ */ React9.createElement(ParentBodyPathProvider_default, { value: "returnType" }, typeof returnType === "string" ? /* @__PURE__ */ React9.createElement(TypeAnnotation_default, null, returnType) : returnType, ";");
    }
    function renderParams() {
      if (!params?.length)
        return null;
      return /* @__PURE__ */ React9.createElement(ParentBodyPathProvider_default, { value: "params" }, params.map((param) => {
        if (typeof param === "string") {
          return /* @__PURE__ */ React9.createElement(Identifier_default, { key: param }, param);
        }
        return param;
      }));
    }
    return /* @__PURE__ */ React9.createElement(
      Smart_default,
      {
        code,
        deletePaths: "body.body",
        ref: mergedRef,
        scopePath: "body.body.0"
      },
      /* @__PURE__ */ React9.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderReturnType(), renderParams(), /* @__PURE__ */ React9.createElement(BlockStatement_default, null, renderChildren()))
    );
  }
);
var ClassMethodAccessibility = /* @__PURE__ */ ((ClassMethodAccessibility2) => {
  ClassMethodAccessibility2["Private"] = "private";
  ClassMethodAccessibility2["Protected"] = "protected";
  ClassMethodAccessibility2["Public"] = "public";
  return ClassMethodAccessibility2;
})(ClassMethodAccessibility || {});
ClassMethod.defaultProps = {
  debug: false
};
var ClassMethod_default = ClassMethod;

// src/components/classes/ClassProperty/index.tsx
import React10, { forwardRef as forwardRef10 } from "react";
import useMergedRef10 from "@react-hook/merged-ref";
var ClassProperty = forwardRef10(
  (props, forwardedRef) => {
    const { accessibility, children, debug, name, typeAnnotation } = props;
    const mergedRef = useMergedRef10(forwardedRef, debugRef(debug));
    const code = `class C {
  ${accessibility ? `${accessibility} ` : ""}${props.static ? "static " : ""}${name}${typeAnnotation ? ": T" : ""}${typeof children !== "undefined" ? ` = ${JSON.stringify(children)}` : ""}
}`;
    function renderTypeAnnotation() {
      if (!typeAnnotation)
        return null;
      return /* @__PURE__ */ React10.createElement(ParentBodyPathProvider_default, { value: "typeAnnotation" }, typeof typeAnnotation === "string" ? /* @__PURE__ */ React10.createElement(TypeAnnotation_default, null, typeAnnotation) : typeAnnotation);
    }
    return /* @__PURE__ */ React10.createElement(Smart_default, { scopePath: "body.body.0", code, ref: mergedRef }, renderTypeAnnotation());
  }
);
var ClassPropertyAccessibility = /* @__PURE__ */ ((ClassPropertyAccessibility2) => {
  ClassPropertyAccessibility2["Private"] = "private";
  ClassPropertyAccessibility2["Protected"] = "protected";
  ClassPropertyAccessibility2["Public"] = "public";
  return ClassPropertyAccessibility2;
})(ClassPropertyAccessibility || {});
ClassProperty.defaultProps = { debug: false };
var ClassProperty_default = ClassProperty;

// src/components/expressions/ArrayExpression/index.tsx
import React11, { forwardRef as forwardRef11 } from "react";
import useMergedRef11 from "@react-hook/merged-ref";
var ArrayExpression = forwardRef11(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef11(forwardedRef, debugRef(debug));
    const code = `var a = []`;
    function renderChildren() {
      if (!children)
        return;
      return children;
    }
    return /* @__PURE__ */ React11.createElement(Smart_default, { scopePath: "declarations.0.init", code, ref: mergedRef }, /* @__PURE__ */ React11.createElement(ParentBodyPathProvider_default, { value: "elements" }, renderChildren()));
  }
);
var ArrayExpression_default = ArrayExpression;

// src/components/expressions/AssignmentExpression/index.tsx
import React12, { forwardRef as forwardRef12 } from "react";
import useMergedRef12 from "@react-hook/merged-ref";
var AssignmentExpression = forwardRef12(
  (props, forwardedRef) => {
    const { children, debug, left } = props;
    const mergedRef = useMergedRef12(forwardedRef, debugRef(debug));
    const childrenIsComponent = isComponent(children);
    const leftIsComponent = isComponent(left);
    function isComponent(value) {
      if (typeof value === "undefined")
        return false;
      const valueKeys = new Set(Object.keys(value || {}));
      return valueKeys.has("$$typeof") && valueKeys.has("key") && valueKeys.has("props") && valueKeys.has("ref") && valueKeys.has("type");
    }
    const code = `${leftIsComponent ? "l" : left} = ${typeof children !== "undefined" && !childrenIsComponent ? `${JSON.stringify(children)}` : "undefined"}`;
    function renderChildren() {
      if (!childrenIsComponent)
        return null;
      return children;
    }
    function renderLeft() {
      if (!leftIsComponent)
        return null;
      return /* @__PURE__ */ React12.createElement(ParentBodyPathProvider_default, { value: "left" }, left);
    }
    return /* @__PURE__ */ React12.createElement(
      Smart_default,
      {
        bodyPath: "right",
        code,
        deletePaths: leftIsComponent ? "left" : void 0,
        ref: mergedRef,
        scopePath: "expression"
      },
      /* @__PURE__ */ React12.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderLeft(), renderChildren())
    );
  }
);
AssignmentExpression.defaultProps = {
  debug: false
};
var AssignmentExpression_default = AssignmentExpression;

// src/components/expressions/AwaitExpression/index.tsx
import React13, { forwardRef as forwardRef13 } from "react";
import useMergedRef13 from "@react-hook/merged-ref";
var AwaitExpression = forwardRef13(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef13(forwardedRef, debugRef(debug));
    const code = `await fetchData(url)`;
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React13.createElement(Identifier_default, null, children);
      }
      return children;
    }
    return /* @__PURE__ */ React13.createElement(Smart_default, { code, ref: mergedRef, scopePath: "expression" }, /* @__PURE__ */ React13.createElement(ParentBodyPathProvider_default, { value: "argument" }, renderChildren()));
  }
);
var AwaitExpression_default = AwaitExpression;

// src/components/expressions/CallExpression/index.tsx
import React14, { forwardRef as forwardRef14 } from "react";
import useMergedRef14 from "@react-hook/merged-ref";
var CallExpression = forwardRef14(
  (props, forwardedRef) => {
    const { children, debug, name } = props;
    const mergedRef = useMergedRef14(forwardedRef, debugRef(debug));
    const code = `${typeof children === "undefined" ? "" : "a."}${name}()`;
    function renderArgument(argument, index) {
      if (typeof argument === "string") {
        return /* @__PURE__ */ React14.createElement(Identifier_default, { key: index }, argument);
      } else if (React14.isValidElement(argument)) {
        return React14.cloneElement(argument, { key: index });
      }
      return;
    }
    function renderArguments() {
      if (!props.arguments)
        return null;
      return /* @__PURE__ */ React14.createElement(ParentBodyPathProvider_default, { value: "arguments" }, Array.isArray(props.arguments) ? props.arguments.map(renderArgument) : renderArgument(props.arguments, 0));
    }
    return /* @__PURE__ */ React14.createElement(
      Smart_default,
      {
        code,
        ref: mergedRef,
        scopePath: "expression",
        bodyPath: "callee.object"
      },
      /* @__PURE__ */ React14.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderArguments(), children)
    );
  }
);
CallExpression.defaultProps = {
  debug: false
};
var CallExpression_default = CallExpression;

// src/components/expressions/MemberExpression/index.tsx
import React15, { forwardRef as forwardRef15 } from "react";
import useMergedRef15 from "@react-hook/merged-ref";
var MemberExpression = forwardRef15(
  (props, forwardedRef) => {
    const { debug, children, name } = props;
    const mergedRef = useMergedRef15(forwardedRef, debugRef(debug));
    const code = `a.${name}`;
    return /* @__PURE__ */ React15.createElement(
      Smart_default,
      {
        bodyPath: "object",
        deletePaths: typeof children === "undefined" ? "object" : void 0,
        code,
        ref: mergedRef,
        scopePath: "expression"
      },
      /* @__PURE__ */ React15.createElement(ParentBodyPathProvider_default, { value: void 0 }, children)
    );
  }
);
MemberExpression.defaultProps = {
  debug: false
};
var MemberExpression_default = MemberExpression;

// src/components/expressions/Expression/index.tsx
import React16, { forwardRef as forwardRef16 } from "react";
import useMergedRef16 from "@react-hook/merged-ref";
var Expression = forwardRef16(
  (props, forwardedRef) => {
    const { call, children, debug } = props;
    const mergedRef = useMergedRef16(forwardedRef, debugRef(debug));
    function renderAssignmentExpression() {
      const properties = renderProperties(
        (typeof props.identifiers === "string" ? props.identifiers.split(".") : props.identifiers) || []
      );
      if (typeof children !== "undefined") {
        return /* @__PURE__ */ React16.createElement(AssignmentExpression_default, { left: properties }, children);
      }
      return properties;
    }
    function renderProperties(properties) {
      const Comp = properties.reverse().reduce(
        (Comp2, property, i) => {
          let NewComp = ({ children: children2 }) => /* @__PURE__ */ React16.createElement(Comp2, null, call && i === 0 ? /* @__PURE__ */ React16.createElement(CallExpression_default, { arguments: props.arguments, name: property }, children2) : /* @__PURE__ */ React16.createElement(MemberExpression_default, { name: property }, children2));
          if (i === properties.length - 1) {
            NewComp = () => /* @__PURE__ */ React16.createElement(Comp2, null, call && properties.length <= 1 ? /* @__PURE__ */ React16.createElement(CallExpression_default, { arguments: props.arguments, name: property }) : /* @__PURE__ */ React16.createElement(Identifier_default, { ref: mergedRef }, property));
          }
          return NewComp;
        },
        ({ children: children2 }) => /* @__PURE__ */ React16.createElement(React16.Fragment, null, children2)
      );
      return /* @__PURE__ */ React16.createElement(Comp, null);
    }
    return renderAssignmentExpression();
  }
);
Expression.defaultProps = {
  call: false,
  debug: false
};
var Expression_default = Expression;

// src/components/expressions/ExpressionStatement/index.tsx
import React17, { forwardRef as forwardRef17 } from "react";
import useMergedRef17 from "@react-hook/merged-ref";
var ExpressionStatement = forwardRef17(
  (props, forwardedRef) => {
    const { debug, children } = props;
    const mergedRef = useMergedRef17(forwardedRef, debugRef(debug));
    const code = `${children ? "i" : ""};`;
    return /* @__PURE__ */ React17.createElement(
      Smart_default,
      {
        code,
        ref: mergedRef,
        deletePaths: "expression",
        bodyPath: "expression"
      },
      /* @__PURE__ */ React17.createElement(ParentBodyPathProvider_default, { value: void 0 }, children)
    );
  }
);
ExpressionStatement.defaultProps = {
  debug: false
};
var ExpressionStatement_default = ExpressionStatement;

// src/components/expressions/NewExpression/index.tsx
import React18, { forwardRef as forwardRef18 } from "react";
import useMergedRef18 from "@react-hook/merged-ref";
var NewExpression = forwardRef18(
  (props, forwardedRef) => {
    const { children, debug, name } = props;
    const mergedRef = useMergedRef18(forwardedRef, debugRef(debug));
    const code = `new ${typeof children === "undefined" ? "" : "a."}${name}()`;
    function renderArgument(argument) {
      if (typeof argument === "string") {
        return /* @__PURE__ */ React18.createElement(Identifier_default, null, argument);
      }
      return argument;
    }
    function renderArguments() {
      if (!props.arguments)
        return null;
      return /* @__PURE__ */ React18.createElement(ParentBodyPathProvider_default, { value: "arguments" }, Array.isArray(props.arguments) ? props.arguments.map(renderArgument) : renderArgument(props.arguments));
    }
    return /* @__PURE__ */ React18.createElement(
      Smart_default,
      {
        code,
        ref: mergedRef,
        scopePath: "expression",
        bodyPath: "callee.object"
      },
      /* @__PURE__ */ React18.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderArguments(), children)
    );
  }
);
NewExpression.defaultProps = {
  debug: false
};
var NewExpression_default = NewExpression;

// src/components/expressions/ObjectExpression/index.tsx
import React19, { forwardRef as forwardRef19 } from "react";
import useMergedRef19 from "@react-hook/merged-ref";
var ObjectExpression = forwardRef19(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef19(forwardedRef, debugRef(debug));
    const code = `var a = {}`;
    function renderProperties() {
      if (children)
        return children;
      return;
    }
    return /* @__PURE__ */ React19.createElement(Smart_default, { code, scopePath: "declarations.0.init", ref: mergedRef }, /* @__PURE__ */ React19.createElement(ParentBodyPathProvider_default, { value: "properties" }, renderProperties()));
  }
);
var ObjectExpression_default = ObjectExpression;

// src/components/expressions/Property/index.tsx
import React20, { forwardRef as forwardRef20 } from "react";
import useMergedRef20 from "@react-hook/merged-ref";
var Property = forwardRef20(
  (props, forwardedRef) => {
    const { name, children, debug } = props;
    const mergedRef = useMergedRef20(forwardedRef, debugRef(debug));
    const code = `var a = { ${typeof name === "string" ? name : "a"} ${children ? `: 1` : ""}}`;
    function renderName() {
      if (!name)
        return null;
      return /* @__PURE__ */ React20.createElement(ParentBodyPathProvider_default, { value: "key" }, name);
    }
    function renderChildren() {
      if (!children)
        return null;
      return /* @__PURE__ */ React20.createElement(ParentBodyPathProvider_default, { value: "value" }, children);
    }
    return /* @__PURE__ */ React20.createElement(
      Smart_default,
      {
        code,
        scopePath: "declarations.0.init.properties.0",
        deletePaths: [
          "declarations.0.init.properties.0.value",
          "declarations.0.init.properties.0.key"
        ],
        ref: mergedRef
      },
      renderName(),
      renderChildren()
    );
  }
);
var Property_default = Property;

// src/components/functions/ArrowFunctionExpression/index.tsx
import React21, { forwardRef as forwardRef21 } from "react";
import useMergedRef21 from "@react-hook/merged-ref";
var ArrowFunctionExpression = forwardRef21((props, forwardedRef) => {
  const { children, debug, returnType, params } = props;
  const mergedRef = useMergedRef21(forwardedRef, debugRef(debug));
  const code = `${props.async ? "async" : ""} ()${returnType ? ": T" : ""} => {}`;
  function renderChildren() {
    if (typeof children === "string") {
      return /* @__PURE__ */ React21.createElement(Code_default, null, children);
    }
    return children;
  }
  function renderReturnType() {
    if (!returnType)
      return null;
    return /* @__PURE__ */ React21.createElement(ParentBodyPathProvider_default, { value: "returnType" }, typeof returnType === "string" ? /* @__PURE__ */ React21.createElement(TypeAnnotation_default, null, returnType) : returnType, ";");
  }
  function renderParams() {
    if (!params?.length)
      return null;
    return /* @__PURE__ */ React21.createElement(ParentBodyPathProvider_default, { value: "params" }, params.map((param) => {
      if (typeof param === "string") {
        return /* @__PURE__ */ React21.createElement(Identifier_default, { key: param }, param);
      }
      return param;
    }));
  }
  return /* @__PURE__ */ React21.createElement(
    Smart_default,
    {
      code,
      deletePaths: "body.body",
      ref: mergedRef,
      scopePath: "expression"
    },
    /* @__PURE__ */ React21.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderReturnType(), renderParams(), /* @__PURE__ */ React21.createElement(BlockStatement_default, null, renderChildren()))
  );
});
ArrowFunctionExpression.defaultProps = {
  debug: false
};
var ArrowFunctionExpression_default = ArrowFunctionExpression;

// src/components/functions/FunctionDeclaration/index.tsx
import React22, { forwardRef as forwardRef22 } from "react";
import useMergedRef22 from "@react-hook/merged-ref";
var FunctionDeclaration = forwardRef22(
  (props, forwardedRef) => {
    const { children, name, debug, returnType, params } = props;
    const mergedRef = useMergedRef22(forwardedRef, debugRef(debug));
    const code = `var f = ${props.async ? "async" : ""} function ${name || ""}()${returnType ? ": T" : ""} {}`;
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React22.createElement(Code_default, null, children);
      }
      return children;
    }
    function renderReturnType() {
      if (!returnType)
        return null;
      return /* @__PURE__ */ React22.createElement(ParentBodyPathProvider_default, { value: "returnType" }, typeof returnType === "string" ? /* @__PURE__ */ React22.createElement(TypeAnnotation_default, null, returnType) : returnType, ";");
    }
    function renderParams() {
      if (!params?.length)
        return null;
      return /* @__PURE__ */ React22.createElement(ParentBodyPathProvider_default, { value: "params" }, params.map((param) => {
        if (typeof param === "string") {
          return /* @__PURE__ */ React22.createElement(Identifier_default, { key: param }, param);
        }
        return param;
      }));
    }
    return /* @__PURE__ */ React22.createElement(
      Smart_default,
      {
        code,
        deletePaths: "body.body",
        ref: mergedRef,
        scopePath: "declarations.0.init"
      },
      /* @__PURE__ */ React22.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderReturnType(), renderParams(), /* @__PURE__ */ React22.createElement(BlockStatement_default, null, renderChildren()))
    );
  }
);
FunctionDeclaration.defaultProps = {
  debug: false
};
var FunctionDeclaration_default = FunctionDeclaration;

// src/components/functions/Function/index.tsx
import React23, { forwardRef as forwardRef23 } from "react";
import useMergedRef23 from "@react-hook/merged-ref";
var Function = forwardRef23(
  (props, forwardedRef) => {
    const clonedProps = { ...props };
    delete clonedProps.name;
    const { arrow, debug, name } = props;
    const mergedRef = useMergedRef23(forwardedRef, debugRef(debug));
    if (arrow) {
      return /* @__PURE__ */ React23.createElement(ArrowFunctionExpression_default, { ...clonedProps, ref: mergedRef });
    }
    return /* @__PURE__ */ React23.createElement(FunctionDeclaration_default, { ...clonedProps, name, ref: mergedRef });
  }
);
Function.defaultProps = {
  arrow: false,
  debug: false
};
var Function_default = Function;

// src/components/functions/Return/index.tsx
import React25, { forwardRef as forwardRef25 } from "react";

// src/components/functions/ReturnStatement/index.tsx
import React24, { forwardRef as forwardRef24 } from "react";
import useMergedRef24 from "@react-hook/merged-ref";
var ReturnStatement = forwardRef24(
  (props, forwardedRef) => {
    const { debug, children } = props;
    const mergedRef = useMergedRef24(forwardedRef, debugRef(debug));
    const isComponent = (() => {
      if (typeof children === "undefined")
        return false;
      const childrenKeys = new Set(Object.keys(children || {}));
      return childrenKeys.has("$$typeof") && childrenKeys.has("key") && childrenKeys.has("props") && childrenKeys.has("ref") && childrenKeys.has("type");
    })();
    const code = `return ${typeof children !== "undefined" && !isComponent ? `${JSON.stringify(children)}` : ""}`;
    function renderChildren() {
      if (!isComponent)
        return null;
      return /* @__PURE__ */ React24.createElement(ParentBodyPathProvider_default, { value: "argument" }, children);
    }
    return /* @__PURE__ */ React24.createElement(Smart_default, { code, ref: mergedRef }, /* @__PURE__ */ React24.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren()));
  }
);
ReturnStatement.defaultProps = {
  debug: false
};
var ReturnStatement_default = ReturnStatement;

// src/components/functions/Return/index.tsx
import useMergedRef25 from "@react-hook/merged-ref";
var Return = forwardRef25(
  (props, forwardedRef) => {
    const clonedProps = { ...props };
    delete clonedProps.debug;
    const { debug } = props;
    const mergedRef = useMergedRef25(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React25.createElement(ReturnStatement_default, { ...clonedProps, ref: mergedRef });
  }
);
Return.defaultProps = {
  debug: false
};
var Return_default = Return;

// src/components/interfaces/ExpressionWithTypeArguments/index.tsx
import React26, { forwardRef as forwardRef26 } from "react";
import useMergedRef26 from "@react-hook/merged-ref";
var ExpressionWithTypeArguments = forwardRef26((props, forwardedRef) => {
  const { children, debug, name } = props;
  const mergedRef = useMergedRef26(forwardedRef, debugRef(debug));
  const code = `interface A extends ${name}<C> {}`;
  return /* @__PURE__ */ React26.createElement(
    Smart_default,
    {
      scopePath: "extends.0",
      bodyPath: "typeParameters.params",
      deletePaths: "typeParameters.params.0",
      code,
      ref: mergedRef
    },
    children
  );
});
ExpressionWithTypeArguments.defaultProps = { debug: false };
var ExpressionWithTypeArguments_default = ExpressionWithTypeArguments;

// src/components/interfaces/Interface/index.tsx
import React28, { forwardRef as forwardRef28 } from "react";
import useMergedRef28 from "@react-hook/merged-ref";

// src/components/interfaces/InterfaceDeclaration/index.tsx
import React27, { forwardRef as forwardRef27 } from "react";
import useMergedRef27 from "@react-hook/merged-ref";
var InterfaceDeclaration = forwardRef27(
  (props, forwardedRef) => {
    const { children, debug, name, typeParameters } = props;
    const mergedRef = useMergedRef27(forwardedRef, debugRef(debug));
    const code = `interface ${name} ${props.extends ? "extends b" : ""} {}`;
    function renderExtends() {
      if (!props.extends)
        return;
      return /* @__PURE__ */ React27.createElement(ParentBodyPathProvider_default, { value: "extends" }, props.extends);
    }
    function renderTypeParameter(typeParameter, index) {
      if (typeof typeParameter === "string") {
        return /* @__PURE__ */ React27.createElement(TypeReference_default, { key: index, name: typeParameter });
      } else if (React27.isValidElement(typeParameter)) {
        return React27.cloneElement(typeParameter, { key: index });
      }
      return null;
    }
    function renderTypeParameters() {
      if (!typeParameters)
        return null;
      return /* @__PURE__ */ React27.createElement(ParentBodyPathProvider_default, { value: "typeParameters" }, /* @__PURE__ */ React27.createElement(TypeParameterDeclaration_default, null, Array.isArray(typeParameters) ? typeParameters.map(
        (typeParameter, index) => renderTypeParameter(typeParameter, index)
      ) : renderTypeParameter(typeParameters, 0)));
    }
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React27.createElement(Code_default, null, children);
      }
      return children;
    }
    return /* @__PURE__ */ React27.createElement(Smart_default, { code, deletePaths: "extends.0", ref: mergedRef }, /* @__PURE__ */ React27.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderTypeParameters(), renderExtends(), /* @__PURE__ */ React27.createElement(BlockStatement_default, null, renderChildren())));
  }
);
InterfaceDeclaration.defaultProps = {
  debug: false
};
var InterfaceDeclaration_default = InterfaceDeclaration;

// src/components/interfaces/Interface/index.tsx
var Interface = forwardRef28(
  (props, forwardedRef) => {
    const clonedProps = { ...props };
    delete clonedProps.debug;
    delete clonedProps.name;
    const { debug, name } = props;
    const mergedRef = useMergedRef28(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React28.createElement(InterfaceDeclaration_default, { ...clonedProps, name, ref: mergedRef });
  }
);
Interface.defaultProps = {
  debug: false
};
var Interface_default = Interface;

// src/components/interfaces/InterfaceTypeReference/index.tsx
import React29, { forwardRef as forwardRef29 } from "react";
import useMergedRef29 from "@react-hook/merged-ref";
var InterfaceTypeReference = forwardRef29((props, forwardedRef) => {
  const { children, debug } = props;
  const mergedRef = useMergedRef29(forwardedRef, debugRef(debug));
  const code = `interface A extends B<${children}> {}`;
  return /* @__PURE__ */ React29.createElement(ParentBodyPathProvider_default, { value: "typeParameters.params" }, /* @__PURE__ */ React29.createElement(
    Smart_default,
    {
      scopePath: "extends.0.typeParameters.params.0",
      code,
      ref: mergedRef
    }
  ));
});
InterfaceTypeReference.defaultProps = { debug: false };
var InterfaceTypeReference_default = InterfaceTypeReference;

// src/components/interfaces/MethodSignature/index.tsx
import React30, { forwardRef as forwardRef30 } from "react";
import useMergedRef30 from "@react-hook/merged-ref";
var MethodSignature = forwardRef30(
  (props, forwardedRef) => {
    const { children, name, debug, optional, returnType, params } = props;
    const mergedRef = useMergedRef30(forwardedRef, debugRef(debug));
    const code = `interface I { ${name}${optional ? "?" : ""}(): ${returnType ? "T" : "any"}; }`;
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React30.createElement(Code_default, null, children);
      }
      return children;
    }
    function renderReturnType() {
      if (!returnType)
        return null;
      return /* @__PURE__ */ React30.createElement(ParentBodyPathProvider_default, { value: "typeAnnotation" }, typeof returnType === "string" ? /* @__PURE__ */ React30.createElement(TypeAnnotation_default, null, returnType) : returnType, ";");
    }
    function renderParams() {
      if (!params?.length)
        return null;
      return /* @__PURE__ */ React30.createElement(ParentBodyPathProvider_default, { value: "parameters" }, params.map((param, i) => {
        if (typeof param === "string") {
          return /* @__PURE__ */ React30.createElement(Identifier_default, { key: `${param}${i}` }, param);
        }
        return param;
      }));
    }
    return /* @__PURE__ */ React30.createElement(Smart_default, { scopePath: "body.body.0", code, ref: mergedRef }, /* @__PURE__ */ React30.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderReturnType(), renderParams(), /* @__PURE__ */ React30.createElement(BlockStatement_default, null, renderChildren())));
  }
);
MethodSignature.defaultProps = {
  debug: false
};
var MethodSignature_default = MethodSignature;

// src/components/interfaces/PropertySignature/index.tsx
import React31, { forwardRef as forwardRef31 } from "react";
import useMergedRef31 from "@react-hook/merged-ref";
var PropertySignature = forwardRef31(
  (props, forwardedRef) => {
    const { debug, name, optional, typeAnnotation } = props;
    const mergedRef = useMergedRef31(forwardedRef, debugRef(debug));
    const code = `interface I {
  ${name}${typeAnnotation ? `${optional ? "?" : ""}: T` : ""};
}`;
    function renderTypeAnnotation() {
      if (!typeAnnotation)
        return null;
      return /* @__PURE__ */ React31.createElement(ParentBodyPathProvider_default, { value: "typeAnnotation" }, typeof typeAnnotation === "string" ? /* @__PURE__ */ React31.createElement(TypeAnnotation_default, null, typeAnnotation) : typeAnnotation);
    }
    return /* @__PURE__ */ React31.createElement(Smart_default, { scopePath: "body.body.0", code, ref: mergedRef }, renderTypeAnnotation());
  }
);
PropertySignature.defaultProps = { debug: false };
var PropertySignature_default = PropertySignature;

// src/components/jsx/JsxClosingElement/index.tsx
import React32, { forwardRef as forwardRef32 } from "react";
import useMergedRef32 from "@react-hook/merged-ref";
var JSXClosingElement = forwardRef32(
  (props, forwardedRef) => {
    const { debug, name } = props;
    const mergedRef = useMergedRef32(forwardedRef, debugRef(debug));
    const code = `<${typeof name === "undefined" ? "" : name}></${typeof name === "undefined" ? "" : name}>`;
    return /* @__PURE__ */ React32.createElement(
      Smart_default,
      {
        code,
        ref: mergedRef,
        scopePath: "expression.closingElement"
      }
    );
  }
);
JSXClosingElement.defaultProps = {
  debug: false
};
var JsxClosingElement_default = JSXClosingElement;

// src/components/jsx/JsxExpressionContainer/index.tsx
import React33, { forwardRef as forwardRef33 } from "react";
import useMergedRef33 from "@react-hook/merged-ref";
var JSXExpressionContainer = forwardRef33((props, forwardedRef) => {
  const { children, debug } = props;
  const mergedRef = useMergedRef33(forwardedRef, debugRef(debug));
  const isComponent = (() => {
    if (typeof children === "undefined")
      return false;
    const childrenKeys = new Set(Object.keys(children || {}));
    return childrenKeys.has("$$typeof") && childrenKeys.has("key") && childrenKeys.has("props") && childrenKeys.has("ref") && childrenKeys.has("type");
  })();
  const code = `<J a={${typeof children !== "undefined" && !isComponent ? `${JSON.stringify(children)}` : "a"}} />`;
  function renderChildren() {
    if (isComponent)
      return children;
    return null;
  }
  return /* @__PURE__ */ React33.createElement(
    Smart_default,
    {
      bodyPath: "expression",
      code,
      deletePaths: typeof children !== "undefined" && !isComponent ? void 0 : "expression",
      ref: mergedRef,
      scopePath: "expression.openingElement.attributes.0.value"
    },
    /* @__PURE__ */ React33.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren())
  );
});
JSXExpressionContainer.defaultProps = { debug: false };
var JsxExpressionContainer_default = JSXExpressionContainer;

// src/components/jsx/JsxAttribute/index.tsx
import React34, { forwardRef as forwardRef34 } from "react";
import useMergedRef34 from "@react-hook/merged-ref";
var JSXAttribute = forwardRef34(
  (props, forwardedRef) => {
    const { children, name, debug } = props;
    const mergedRef = useMergedRef34(forwardedRef, debugRef(debug));
    const code = `<J ${name}${typeof children === "string" ? `=${JSON.stringify(children)}` : ""} />`;
    function renderChildren() {
      if (typeof children === "undefined" || typeof children === "string" || children === null) {
        return null;
      }
      return /* @__PURE__ */ React34.createElement(JsxExpressionContainer_default, null, children);
    }
    return /* @__PURE__ */ React34.createElement(
      Smart_default,
      {
        scopePath: "expression.openingElement.attributes.0",
        bodyPath: "value",
        code,
        ref: mergedRef
      },
      /* @__PURE__ */ React34.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren())
    );
  }
);
JSXAttribute.defaultProps = { debug: false };
var JsxAttribute_default = JSXAttribute;

// src/components/jsx/JsxOpeningElement/index.tsx
import React35, { forwardRef as forwardRef35 } from "react";
import useMergedRef35 from "@react-hook/merged-ref";
var JSXOpeningElement = forwardRef35(
  (props, forwardedRef) => {
    const { attributes, debug, name, selfClosing } = props;
    const mergedRef = useMergedRef35(forwardedRef, debugRef(debug));
    const code = `<${typeof name === "undefined" ? "" : name}${typeof name !== "undefined" && selfClosing ? " /" : `></${typeof name === "undefined" ? "" : name}`}>`;
    function isComponent(value) {
      if (typeof value === "undefined")
        return false;
      const childrenKeys = new Set(Object.keys(value || {}));
      return childrenKeys.has("$$typeof") && childrenKeys.has("key") && childrenKeys.has("props") && childrenKeys.has("ref") && childrenKeys.has("type");
    }
    function renderAttribute(attribute, name2) {
      if (name2) {
        return /* @__PURE__ */ React35.createElement(JsxAttribute_default, { name: name2, key: name2 }, attribute === true ? void 0 : attribute);
      }
      if (typeof attribute === "string") {
        return /* @__PURE__ */ React35.createElement(JsxAttribute_default, { name: attribute, key: attribute });
      }
      if (isComponent(attribute))
        return attribute;
      return null;
    }
    function renderAttributes() {
      if (!attributes)
        return null;
      if (typeof attributes === "string") {
        return /* @__PURE__ */ React35.createElement(JsxAttribute_default, { name: attributes, key: attributes });
      }
      if (isComponent(attributes))
        return attributes;
      if (Array.isArray(attributes)) {
        return attributes.map(
          (attribute) => renderAttribute(attribute)
        );
      }
      if (typeof attributes === "object") {
        return Object.entries(attributes).map(
          ([name2, attribute]) => renderAttribute(attribute, name2)
        );
      }
      return null;
    }
    return /* @__PURE__ */ React35.createElement(
      Smart_default,
      {
        code,
        ref: mergedRef,
        bodyPath: "attributes",
        scopePath: "expression.openingElement"
      },
      /* @__PURE__ */ React35.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderAttributes())
    );
  }
);
JSXOpeningElement.defaultProps = {
  debug: false,
  selfClosing: false
};
var JsxOpeningElement_default = JSXOpeningElement;

// src/components/jsx/JsxElement/index.tsx
import React36, { forwardRef as forwardRef36 } from "react";
import useMergedRef36 from "@react-hook/merged-ref";
var JsxElement = forwardRef36(
  (props, forwardedRef) => {
    const { attributes, selfClosing, children, debug, name } = props;
    const mergedRef = useMergedRef36(forwardedRef, debugRef(debug));
    const code = `<${typeof name === "undefined" ? "" : "E"}${children || !name ? `></${typeof name === "undefined" ? "" : "E"}` : " /"}>`;
    function renderOpeningElement() {
      return /* @__PURE__ */ React36.createElement(ParentBodyPathProvider_default, { value: "openingElement" }, /* @__PURE__ */ React36.createElement(
        JsxOpeningElement_default,
        {
          attributes,
          name,
          selfClosing: !children && selfClosing
        }
      ));
    }
    function renderClosingElement() {
      return /* @__PURE__ */ React36.createElement(ParentBodyPathProvider_default, { value: "closingElement" }, /* @__PURE__ */ React36.createElement(JsxClosingElement_default, { name }));
    }
    function renderChildren() {
      return children;
    }
    return /* @__PURE__ */ React36.createElement(
      Smart_default,
      {
        code,
        scopePath: "expression",
        bodyPath: "children",
        ref: mergedRef
      },
      /* @__PURE__ */ React36.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderOpeningElement(), renderClosingElement(), renderChildren())
    );
  }
);
JsxElement.defaultProps = {
  debug: false,
  selfClosing: true
};
var JsxElement_default = JsxElement;

// src/components/jsx/Jsx/index.tsx
import React37, { forwardRef as forwardRef37 } from "react";
import useMergedRef37 from "@react-hook/merged-ref";
var Jsx = forwardRef37(
  (props, forwardedRef) => {
    const clonedProps = { ...props };
    delete clonedProps.debug;
    const { debug } = props;
    const mergedRef = useMergedRef37(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React37.createElement(JsxElement_default, { ...clonedProps, ref: mergedRef });
  }
);
Jsx.defaultProps = {
  debug: false
};
var Jsx_default = Jsx;

// src/components/modules/ExportDefaultDeclaration/index.tsx
import React38, { forwardRef as forwardRef38 } from "react";
import useMergedRef38 from "@react-hook/merged-ref";
var ExportDefaultDeclaration = forwardRef38((props, forwardedRef) => {
  const { children, debug } = props;
  const mergedRef = useMergedRef38(forwardedRef, debugRef(debug));
  const code = "export default d";
  function renderChildren() {
    if (typeof children === "string") {
      return /* @__PURE__ */ React38.createElement(Code_default, null, children);
    }
    return children;
  }
  return /* @__PURE__ */ React38.createElement(
    Smart_default,
    {
      bodyPath: "declaration",
      code,
      deletePaths: "declaration",
      ref: mergedRef
    },
    /* @__PURE__ */ React38.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren())
  );
});
ExportDefaultDeclaration.defaultProps = {
  debug: false
};
var ExportDefaultDeclaration_default = ExportDefaultDeclaration;

// src/components/modules/ExportNamedDeclaration/index.tsx
import React40, { forwardRef as forwardRef40 } from "react";
import useMergedRef40 from "@react-hook/merged-ref";

// src/components/modules/ExportSpecifier/index.tsx
import React39, { forwardRef as forwardRef39 } from "react";
import useMergedRef39 from "@react-hook/merged-ref";
var ExportSpecifier = forwardRef39(
  (props, forwardedRef) => {
    const { debug, children, local } = props;
    const mergedRef = useMergedRef39(forwardedRef, debugRef(debug));
    const code = `export {${children}${local ? ` as ${local}` : ""}}`;
    return /* @__PURE__ */ React39.createElement(Smart_default, { scopePath: "specifiers.0", code, ref: mergedRef });
  }
);
ExportSpecifier.defaultProps = {
  debug: false
};
var ExportSpecifier_default = ExportSpecifier;

// src/components/modules/ExportNamedDeclaration/index.tsx
var ExportNamedDeclaration = forwardRef40((props, forwardedRef) => {
  const { children, debug, source, specifiers } = props;
  const mergedRef = useMergedRef40(forwardedRef, debugRef(debug));
  const code = `export ${props.exportKind === "type" ? "type" : ""} {}${source ? ` from '${source}'` : ""}`;
  function renderChildren() {
    if (typeof children === "string") {
      return /* @__PURE__ */ React40.createElement(Code_default, null, children);
    }
    return children;
  }
  function renderSpecifier(specifier) {
    if (typeof specifier === "string") {
      return /* @__PURE__ */ React40.createElement(ExportSpecifier_default, null, specifier);
    }
    return specifier;
  }
  function renderSpecifiers() {
    if (!specifiers)
      return null;
    return /* @__PURE__ */ React40.createElement(ParentBodyPathProvider_default, { value: "specifiers" }, Array.isArray(specifiers) ? specifiers.map((specifier, index) => /* @__PURE__ */ React40.createElement(React40.Fragment, { key: index }, renderSpecifier(specifier))) : /* @__PURE__ */ React40.createElement(React40.Fragment, { key: 0 }, renderSpecifier(specifiers)));
  }
  return /* @__PURE__ */ React40.createElement(Smart_default, { code, bodyPath: "declaration", ref: mergedRef }, /* @__PURE__ */ React40.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderSpecifiers(), renderChildren()));
});
ExportNamedDeclaration.defaultProps = {
  debug: false
};
var ExportNamedDeclaration_default = ExportNamedDeclaration;

// src/components/modules/Export/index.tsx
import React41, { forwardRef as forwardRef41 } from "react";
import useMergedRef41 from "@react-hook/merged-ref";
var Export = forwardRef41(
  (props, forwardedRef) => {
    const clonedProps = { ...props };
    delete clonedProps.from;
    delete clonedProps.exports;
    delete clonedProps.debug;
    const { children, exports, debug } = props;
    const mergedRef = useMergedRef41(forwardedRef, debugRef(debug));
    if (props.default) {
      return /* @__PURE__ */ React41.createElement(ExportDefaultDeclaration_default, { ref: mergedRef }, children);
    }
    return /* @__PURE__ */ React41.createElement(
      ExportNamedDeclaration_default,
      {
        ...clonedProps,
        ref: mergedRef,
        source: props.from,
        specifiers: exports
      }
    );
  }
);
Export.defaultProps = {
  debug: false,
  default: false
};
var Export_default = Export;

// src/components/modules/ExportAllDeclaration/index.tsx
import React42, { forwardRef as forwardRef42 } from "react";
import useMergedRef42 from "@react-hook/merged-ref";
var ExportAllDeclaration = forwardRef42(
  (props, forwardedRef) => {
    const { debug, source } = props;
    const mergedRef = useMergedRef42(forwardedRef, debugRef(debug));
    const code = `export * from '${source}'`;
    return /* @__PURE__ */ React42.createElement(Smart_default, { code, ref: mergedRef });
  }
);
ExportAllDeclaration.defaultProps = {
  debug: false
};
var ExportAllDeclaration_default = ExportAllDeclaration;

// src/components/modules/Import/index.tsx
import React45, { forwardRef as forwardRef45 } from "react";
import useMergedRef45 from "@react-hook/merged-ref";

// src/components/modules/ImportDeclaration/index.tsx
import React44, { forwardRef as forwardRef44 } from "react";
import useMergedRef44 from "@react-hook/merged-ref";

// src/components/modules/ImportSpecifier/index.tsx
import React43, { forwardRef as forwardRef43 } from "react";
import useMergedRef43 from "@react-hook/merged-ref";
var ImportSpecifier = forwardRef43(
  (props, forwardedRef) => {
    const { debug, children, local } = props;
    const mergedRef = useMergedRef43(forwardedRef, debugRef(debug));
    const code = `import {${children}${local ? ` as ${local}` : ""}} from 'm'`;
    return /* @__PURE__ */ React43.createElement(Smart_default, { scopePath: "specifiers.0", code, ref: mergedRef });
  }
);
ImportSpecifier.defaultProps = {
  debug: false
};
var ImportSpecifier_default = ImportSpecifier;

// src/components/modules/ImportDeclaration/index.tsx
var ImportDeclaration = forwardRef44(
  (props, forwardedRef) => {
    const { debug, defaultSpecifier, namespaceSpecifier, source, specifiers } = props;
    const mergedRef = useMergedRef44(forwardedRef, debugRef(debug));
    const code = `import ${props.importKind === "type" ? "type" : ""} ${namespaceSpecifier ? ` * as ${namespaceSpecifier}` : defaultSpecifier || "I"} from '${source}'`;
    function renderSpecifier(specifier, i) {
      if (typeof specifier === "string") {
        return /* @__PURE__ */ React44.createElement(
          ImportSpecifier_default,
          {
            key: typeof i !== "undefined" ? i.toString() : void 0
          },
          specifier
        );
      }
      return specifier;
    }
    function renderSpecifiers() {
      if (!specifiers || namespaceSpecifier)
        return null;
      return /* @__PURE__ */ React44.createElement(ParentBodyPathProvider_default, { value: "specifiers" }, Array.isArray(specifiers) ? specifiers.map(renderSpecifier) : renderSpecifier(specifiers));
    }
    return /* @__PURE__ */ React44.createElement(
      Smart_default,
      {
        code,
        deletePaths: defaultSpecifier || namespaceSpecifier ? void 0 : "specifiers.0",
        ref: mergedRef
      },
      /* @__PURE__ */ React44.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderSpecifiers())
    );
  }
);
ImportDeclaration.defaultProps = {
  debug: false
};
var ImportDeclaration_default = ImportDeclaration;

// src/components/modules/Import/index.tsx
var Import = forwardRef45(
  (props, forwardedRef) => {
    const clonedProps = { ...props };
    delete clonedProps.debug;
    delete clonedProps.default;
    delete clonedProps.from;
    delete clonedProps.imports;
    delete clonedProps.namespace;
    const { debug, namespace, imports } = props;
    const mergedRef = useMergedRef45(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React45.createElement(
      ImportDeclaration_default,
      {
        ...clonedProps,
        defaultSpecifier: props.default,
        namespaceSpecifier: namespace,
        ref: mergedRef,
        source: props.from,
        specifiers: imports
      }
    );
  }
);
Import.defaultProps = {
  debug: false
};
var Import_default = Import;

// src/components/modules/ModuleDeclaration/index.tsx
import React46, { forwardRef as forwardRef46 } from "react";
import useMergedRef46 from "@react-hook/merged-ref";
var DeclarationType = /* @__PURE__ */ ((DeclarationType2) => {
  DeclarationType2["Declare"] = "declare";
  DeclarationType2["Namespace"] = "namespace";
  return DeclarationType2;
})(DeclarationType || {});
var ModuleDeclaration = forwardRef46(
  (props, forwardedRef) => {
    const { children, debug, name, declaration } = props;
    const mergedRef = useMergedRef46(forwardedRef, debugRef(debug));
    let code = "";
    if (declaration === "declare" /* Declare */) {
      code = `declare ${name} {}`;
    } else if (declaration === "namespace" /* Namespace */) {
      code = `namespace ${name} {}`;
    }
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React46.createElement(Code_default, null, children);
      }
      return children;
    }
    return /* @__PURE__ */ React46.createElement(Smart_default, { deletePaths: "body", code, ref: mergedRef }, /* @__PURE__ */ React46.createElement(BlockStatement_default, null, renderChildren()));
  }
);
var ModuleDeclaration_default = ModuleDeclaration;

// src/components/react/FunctionalComponent/index.tsx
import React47 from "react";
var FunctionalComponent = (props) => {
  const { children, name } = props;
  return /* @__PURE__ */ React47.createElement(React47.Fragment, null, /* @__PURE__ */ React47.createElement(Import_default, { default: "React", imports: ["FC"], from: "react" }), /* @__PURE__ */ React47.createElement(Export_default, null, /* @__PURE__ */ React47.createElement(Interface_default, { name: `${name}Props` })), /* @__PURE__ */ React47.createElement(Var_default, { kind: VarKind.Const, typeAnnotation: `FC<${name}Props>`, name }, /* @__PURE__ */ React47.createElement(
    Function_default,
    {
      arrow: true,
      params: [
        /* @__PURE__ */ React47.createElement(
          Identifier_default,
          {
            key: 0,
            typeAnnotation: /* @__PURE__ */ React47.createElement(TypeAnnotation_default, null, /* @__PURE__ */ React47.createElement(TypeReference_default, { name: `${name}Props` }))
          },
          "props"
        )
      ]
    },
    /* @__PURE__ */ React47.createElement(Return_default, null, children || /* @__PURE__ */ React47.createElement(Jsx_default, null))
  )), /* @__PURE__ */ React47.createElement(Expression_default, { identifiers: `${name}.defaultProps` }, {}), /* @__PURE__ */ React47.createElement(Export_default, { default: true }, /* @__PURE__ */ React47.createElement(Identifier_default, null, name)));
};
FunctionalComponent.defaultProps = {
  debug: false
};
var FunctionalComponent_default = FunctionalComponent;

// src/components/types/IntersectionType/index.tsx
import React48, { forwardRef as forwardRef47 } from "react";
import useMergedRef47 from "@react-hook/merged-ref";
var IntersectionType = forwardRef47(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef47(forwardedRef, debugRef(debug));
    const code = `type E = A & B`;
    return /* @__PURE__ */ React48.createElement(
      Smart_default,
      {
        deletePaths: ["types.1", "types.0"],
        scopePath: "typeAnnotation",
        code,
        ref: mergedRef
      },
      /* @__PURE__ */ React48.createElement(ParentBodyPathProvider_default, { value: "types" }, children)
    );
  }
);
var IntersectionType_default = IntersectionType;

// src/components/types/TypeAliasDeclaration/index.tsx
import React49, { forwardRef as forwardRef48 } from "react";
import useMergedRef48 from "@react-hook/merged-ref";
var TypeAliasDeclaration = forwardRef48(
  (props, forwardedRef) => {
    const { name, children, debug } = props;
    const mergedRef = useMergedRef48(forwardedRef, debugRef(debug));
    const code = `type ${name} = {}`;
    return /* @__PURE__ */ React49.createElement(Smart_default, { code, ref: mergedRef }, /* @__PURE__ */ React49.createElement(ParentBodyPathProvider_default, { value: "typeAnnotation" }, children));
  }
);
var TypeAliasDeclaration_default = TypeAliasDeclaration;

// src/components/types/TypeParameterInstantiation/index.tsx
import React50, { forwardRef as forwardRef49 } from "react";
import useMergedRef49 from "@react-hook/merged-ref";
var TypeParameterInstantiation = forwardRef49((props, forwardedRef) => {
  const { children, debug } = props;
  const mergedRef = useMergedRef49(forwardedRef, debugRef(debug));
  const code = "const c: T<any> = 0";
  function renderChildren() {
    if (typeof children === "string") {
      return /* @__PURE__ */ React50.createElement(TypeReference_default, { name: children });
    }
    return children;
  }
  return /* @__PURE__ */ React50.createElement(
    Smart_default,
    {
      bodyPath: "params",
      code,
      deletePaths: "params.0",
      ref: mergedRef,
      scopePath: "declarations.0.id.typeAnnotation.typeAnnotation.typeParameters"
    },
    /* @__PURE__ */ React50.createElement(ParentBodyPathProvider_default, { value: void 0 }, renderChildren())
  );
});
TypeParameterInstantiation.defaultProps = { debug: false };
var TypeParameterInstantiation_default = TypeParameterInstantiation;

// src/components/types/UnionType/index.tsx
import React51, { forwardRef as forwardRef50 } from "react";
import useMergedRef50 from "@react-hook/merged-ref";
var UnionType = forwardRef50(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef50(forwardedRef, debugRef(debug));
    const code = `type E = A | B`;
    return /* @__PURE__ */ React51.createElement(
      Smart_default,
      {
        deletePaths: ["types.1", "types.0"],
        scopePath: "typeAnnotation",
        code,
        ref: mergedRef
      },
      /* @__PURE__ */ React51.createElement(ParentBodyPathProvider_default, { value: "types" }, children)
    );
  }
);
var UnionType_default = UnionType;

// src/components/variables/Var/index.tsx
import React54, { forwardRef as forwardRef53 } from "react";
import useMergedRef53 from "@react-hook/merged-ref";

// src/components/variables/VariableDeclarator/index.tsx
import React52, { forwardRef as forwardRef51 } from "react";
import useMergedRef51 from "@react-hook/merged-ref";
var VariableDeclarator = forwardRef51(
  (props, forwardedRef) => {
    const { children, debug, name, typeAnnotation } = props;
    const mergedRef = useMergedRef51(forwardedRef, debugRef(debug));
    const isComponent = (() => {
      if (typeof children === "undefined")
        return false;
      const childrenKeys = new Set(Object.keys(children || {}));
      return childrenKeys.has("$$typeof") && childrenKeys.has("key") && childrenKeys.has("props") && childrenKeys.has("ref") && childrenKeys.has("type");
    })();
    const code = `var ${name}${typeAnnotation ? ": T" : ""}${typeof children !== "undefined" && !isComponent ? ` = ${JSON.stringify(children)}` : ""}`;
    function renderChildren() {
      if (!isComponent || typeof children === "undefined")
        return null;
      return /* @__PURE__ */ React52.createElement(ParentBodyPathProvider_default, { value: "init" }, children);
    }
    function renderTypeAnnotation() {
      if (!typeAnnotation)
        return null;
      return /* @__PURE__ */ React52.createElement(ParentBodyPathProvider_default, { value: "id.typeAnnotation" }, typeof typeAnnotation === "string" ? /* @__PURE__ */ React52.createElement(TypeAnnotation_default, null, typeAnnotation) : typeAnnotation, ";");
    }
    return /* @__PURE__ */ React52.createElement(Smart_default, { code, ref: mergedRef, scopePath: "declarations.0" }, renderTypeAnnotation(), renderChildren());
  }
);
VariableDeclarator.defaultProps = { debug: false };
var VariableDeclarator_default = VariableDeclarator;

// src/components/variables/VariableDeclaration/index.tsx
import React53, { forwardRef as forwardRef52 } from "react";
import useMergedRef52 from "@react-hook/merged-ref";
var VariableDeclaration = forwardRef52(
  (props, forwardedRef) => {
    const { children, debug, kind } = props;
    const mergedRef = useMergedRef52(forwardedRef, debugRef(debug));
    const code = `${kind} v = 0`;
    return /* @__PURE__ */ React53.createElement(
      Smart_default,
      {
        code,
        deletePaths: "declarations.0",
        bodyPath: "declarations",
        ref: mergedRef
      },
      /* @__PURE__ */ React53.createElement(ParentBodyPathProvider_default, { value: void 0 }, children)
    );
  }
);
var VariableDeclarationKind = /* @__PURE__ */ ((VariableDeclarationKind2) => {
  VariableDeclarationKind2["Const"] = "const";
  VariableDeclarationKind2["Let"] = "let";
  VariableDeclarationKind2["Var"] = "var";
  return VariableDeclarationKind2;
})(VariableDeclarationKind || {});
VariableDeclaration.defaultProps = {
  debug: false,
  kind: "var" /* Var */
};
var VariableDeclaration_default = VariableDeclaration;

// src/components/variables/Var/index.tsx
var Var = forwardRef53(
  (props, forwardedRef) => {
    const { children, debug, kind, typeAnnotation, name } = props;
    const mergedRef = useMergedRef53(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React54.createElement(
      VariableDeclaration_default,
      {
        kind,
        ref: mergedRef
      },
      /* @__PURE__ */ React54.createElement(VariableDeclarator_default, { name, typeAnnotation }, children)
    );
  }
);
var VarKind = ((VarKind2) => {
  VarKind2[VarKind2["Const"] = "const" /* Const */] = "Const";
  VarKind2[VarKind2["Let"] = "let" /* Let */] = "Let";
  VarKind2[VarKind2["Var"] = "var" /* Var */] = "Var";
  return VarKind2;
})(VarKind || {});
Var.defaultProps = {
  debug: false,
  kind: VarKind.Var
};
var Var_default = Var;

// src/components/literals/ArrayLiteral/index.tsx
import React55, { forwardRef as forwardRef54 } from "react";
import useMergedRef54 from "@react-hook/merged-ref";
var ArrayLiteral = forwardRef54(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef54(forwardedRef, debugRef(debug));
    const code = `var a = ${children}`;
    return /* @__PURE__ */ React55.createElement(Smart_default, { scopePath: "declarations.0.init", code, ref: mergedRef });
  }
);
var ArrayLiteral_default = ArrayLiteral;

// src/components/literals/BigIntLiteral/index.tsx
import React56, { forwardRef as forwardRef55 } from "react";
import useMergedRef55 from "@react-hook/merged-ref";
var BigIntLiteral = forwardRef55(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef55(forwardedRef, debugRef(debug));
    const code = `var a = ${children}n`;
    return /* @__PURE__ */ React56.createElement(Smart_default, { code, ref: mergedRef, scopePath: "declarations.0.init" });
  }
);
var BigIntLiteral_default = BigIntLiteral;

// src/components/literals/BooleanLiteral/index.tsx
import React57, { forwardRef as forwardRef56 } from "react";
import useMergedRef56 from "@react-hook/merged-ref";
var BooleanLiteral = forwardRef56(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef56(forwardedRef, debugRef(debug));
    const code = `var a = ${children}`;
    return /* @__PURE__ */ React57.createElement(Smart_default, { scopePath: "declarations.0.init", code, ref: mergedRef });
  }
);
var BooleanLiteral_default = BooleanLiteral;

// src/components/literals/Literal/index.tsx
import React58, { forwardRef as forwardRef57 } from "react";
import useMergedRef57 from "@react-hook/merged-ref";
var Literal = forwardRef57(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const mergedRef = useMergedRef57(forwardedRef, debugRef(debug));
    function getLiterals() {
      switch (typeof children) {
        case "boolean":
          return /* @__PURE__ */ React58.createElement(BooleanLiteral_default, { ref: mergedRef, debug }, children);
        case "number":
          return /* @__PURE__ */ React58.createElement(NumericLiteral_default, { ref: mergedRef, debug }, children);
        case "string":
          return /* @__PURE__ */ React58.createElement(StringLiteral_default, { ref: mergedRef, debug }, children);
        case "bigint":
          return /* @__PURE__ */ React58.createElement(BigIntLiteral_default, { ref: mergedRef, debug }, children);
        default:
          return /* @__PURE__ */ React58.createElement(ObjectLiteral_default, { ref: mergedRef, debug }, JSON.stringify(children));
      }
    }
    return /* @__PURE__ */ React58.createElement(React58.Fragment, null, getLiterals());
  }
);
var Literal_default = Literal;

// src/components/literals/NumericLiteral/index.tsx
import React59, { forwardRef as forwardRef58 } from "react";
import useMergedRef58 from "@react-hook/merged-ref";
var NumericLiteral = forwardRef58(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const code = `var a = ${children}`;
    const mergedRef = useMergedRef58(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React59.createElement(Smart_default, { code, ref: mergedRef, scopePath: "declarations.0.init" });
  }
);
var NumericLiteral_default = NumericLiteral;

// src/components/literals/ObjectLiteral/index.tsx
import React60, { forwardRef as forwardRef59 } from "react";
import useMergedRef59 from "@react-hook/merged-ref";
var ObjectLiteral = forwardRef59(
  (props, forwardedRef) => {
    const { children, debug } = props;
    const code = `var a = ${children}`;
    const mergedRef = useMergedRef59(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React60.createElement(Smart_default, { code, ref: mergedRef, scopePath: "declarations.0.init" });
  }
);
var ObjectLiteral_default = ObjectLiteral;

// src/components/literals/StringLiteral/index.tsx
import React61, { forwardRef as forwardRef60 } from "react";
import useMergedRef60 from "@react-hook/merged-ref";
var StringLiteral = forwardRef60(
  (props, forwardedRef) => {
    const { debug } = props;
    const mergedRef = useMergedRef60(forwardedRef, debugRef(debug));
    const code = `var a = "${props.children}"`;
    return /* @__PURE__ */ React61.createElement(Smart_default, { code, ref: mergedRef, scopePath: "declarations.0.init" });
  }
);
var StringLiteral_default = StringLiteral;

// src/components/enum/EnumDeclaration/index.tsx
import React62, { forwardRef as forwardRef61 } from "react";
import useMergedRef61 from "@react-hook/merged-ref";
var EnumDeclaration = forwardRef61(
  (props, forwardedRef) => {
    const { children, debug, name } = props;
    const mergedRef = useMergedRef61(forwardedRef, debugRef(debug));
    const code = `enum ${name} {}`;
    function renderChildren() {
      if (typeof children === "string") {
        return /* @__PURE__ */ React62.createElement(Code_default, null, children);
      }
      return children;
    }
    return /* @__PURE__ */ React62.createElement(Smart_default, { code, deletePaths: "body.body", ref: mergedRef }, /* @__PURE__ */ React62.createElement(ParentBodyPathProvider_default, { value: "members" }, renderChildren()));
  }
);
EnumDeclaration.defaultProps = {
  debug: false
};
var EnumDeclaration_default = EnumDeclaration;

// src/components/enum/EnumMember/index.tsx
import React63, { forwardRef as forwardRef62 } from "react";
import useMergedRef62 from "@react-hook/merged-ref";
var EnumMember = forwardRef62(
  (props, forwardedRef) => {
    const { debug, name, children } = props;
    const mergedRef = useMergedRef62(forwardedRef, debugRef(debug));
    const code = `enum E {
      ${name}${children ? `= "ONE"` : ""},
    }`;
    return /* @__PURE__ */ React63.createElement(
      Smart_default,
      {
        scopePath: "members.0",
        deletePaths: "initializer.value",
        code,
        ref: mergedRef
      },
      /* @__PURE__ */ React63.createElement(ParentBodyPathProvider_default, { value: "initializer" }, children)
    );
  }
);
EnumMember.defaultProps = { debug: false };
var EnumMember_default = EnumMember;

// src/index.ts
var Ast = "Ast";
var ExpressionElement = "ExpressionElement";
var File = "File";
var Program = "Program";
var SmartElement = "SmartElement";

// src/components/Smart/index.tsx
var Smart = forwardRef63(
  (props, forwardedRef) => {
    const { debug } = props;
    const parentBodyPath = useParentBodyPath();
    const mergedRef = useMergedRef63(forwardedRef, debugRef(debug));
    return /* @__PURE__ */ React64.createElement(
      SmartElement,
      {
        ...props,
        ref: mergedRef,
        parentBodyPath
      }
    );
  }
);
Smart.defaultProps = { debug: false };
var Smart_default = Smart;

export {
  Smart_default,
  Code_default,
  BlockStatement_default,
  TypeReference_default,
  TypeAnnotation_default,
  Identifier_default,
  TypeParameterDeclaration_default,
  ClassDeclaration_default,
  Class_default,
  ClassMethodAccessibility,
  ClassMethod_default,
  ClassPropertyAccessibility,
  ClassProperty_default,
  ArrayExpression_default,
  AssignmentExpression_default,
  AwaitExpression_default,
  CallExpression_default,
  MemberExpression_default,
  Expression_default,
  ExpressionStatement_default,
  NewExpression_default,
  ObjectExpression_default,
  Property_default,
  ArrowFunctionExpression_default,
  FunctionDeclaration_default,
  Function_default,
  ReturnStatement_default,
  Return_default,
  ExpressionWithTypeArguments_default,
  InterfaceDeclaration_default,
  Interface_default,
  InterfaceTypeReference_default,
  MethodSignature_default,
  PropertySignature_default,
  JsxClosingElement_default,
  JsxExpressionContainer_default,
  JsxAttribute_default,
  JsxOpeningElement_default,
  JsxElement_default,
  Jsx_default,
  ExportDefaultDeclaration_default,
  ExportSpecifier_default,
  ExportNamedDeclaration_default,
  Export_default,
  ExportAllDeclaration_default,
  ImportSpecifier_default,
  ImportDeclaration_default,
  Import_default,
  DeclarationType,
  ModuleDeclaration_default,
  FunctionalComponent_default,
  IntersectionType_default,
  TypeAliasDeclaration_default,
  TypeParameterInstantiation_default,
  UnionType_default,
  VariableDeclarator_default,
  VariableDeclarationKind,
  VariableDeclaration_default,
  VarKind,
  Var_default,
  ArrayLiteral_default,
  BigIntLiteral_default,
  BooleanLiteral_default,
  Literal_default,
  NumericLiteral_default,
  ObjectLiteral_default,
  StringLiteral_default,
  EnumDeclaration_default,
  EnumMember_default,
  Ast,
  ExpressionElement,
  File,
  Program,
  SmartElement
};
