// src/util.ts
import _get from "lodash.get";
var g = typeof window === "undefined" ? global : window;
var process = typeof g.process === "undefined" ? { env: {} } : g.process;
function flattenPath(path) {
  if (typeof path !== "number" && !path)
    return "";
  if (!Array.isArray(path))
    return path.toString();
  return path.flat().filter((s) => s.toString().length).join(".");
}
function deletePath(value, path) {
  if (typeof value === "undefined")
    return false;
  const pathArr = flattenPath(path).split(".");
  let key = pathArr.slice(pathArr.length - 1)[0];
  key = Number.isNaN(Number(key)) ? key : Number(key);
  const parentDeletePath = pathArr.slice(0, pathArr.length - 1).join(".");
  const parent = parentDeletePath ? _get(value, parentDeletePath) : value;
  if (typeof parent === "undefined")
    return false;
  if (Array.isArray(parent) && typeof key === "number") {
    const result2 = parent.length > key;
    parent.splice(key, 1);
    return result2;
  }
  const result = key in parent;
  delete parent[key];
  return result;
}
function isDev() {
  if (typeof process.env.NODE_ENV === "undefined") {
    return typeof process.env.__DEV__ === "undefined" ? false : process.env.__DEV__.toLowerCase() !== "false";
  }
  return process.env.NODE_ENV.toLowerCase() !== "prod" && process.env.NODE_ENV.toLowerCase() !== "production";
}
var dev = isDev();
var logger = {
  ...console,
  debug: dev ? console.debug : (..._args) => void 0
};
function debugRef(debug = true) {
  if (!debug)
    return () => void 0;
  return (ref) => logger.debug(JSON.stringify(ref.node, null, 2));
}

export {
  flattenPath,
  deletePath,
  dev,
  logger,
  debugRef
};
