import {
  flattenPath
} from "./chunk-BBDMJ3VH.mjs";

// src/elements/BaseElement.ts
import PropTypes from "prop-types";
import _get from "lodash.get";
import _set from "lodash.set";
var BaseElement = class {
  constructor(baseNode, props = {}, meta) {
    this.children = [];
    this.meta = {
      bodyPath: "body",
      parentBodyPath: null
    };
    if (Array.isArray(baseNode))
      throw new Error("cannot be array");
    if (meta) {
      this.meta = {
        ...this.meta,
        ...meta
      };
    }
    this.node = baseNode;
    this.props = this.getProps(props);
  }
  getBodyPath(path) {
    return flattenPath(path || this.meta.bodyPath);
  }
  getBody(body, path) {
    const bodyPath = this.getBodyPath(path);
    if (!bodyPath.length)
      return body;
    return _get(body, bodyPath);
  }
  setBody(body, value, path) {
    const bodyPath = this.getBodyPath(path);
    if (!bodyPath.length)
      return body;
    return _set(body, bodyPath, value);
  }
  appendChild(child) {
    const body = this.getBody(this.node, child.meta.parentBodyPath);
    this.children.push(child);
    if (Array.isArray(body)) {
      body.push(child.node);
    } else {
      this.setBody(this.node, child.node, child.meta.parentBodyPath);
    }
  }
  removeChild(child) {
    const body = this.getBody(this.node, child.meta.parentBodyPath);
    if (!body || !Array.isArray(body))
      return;
    this.children.splice(this.children.indexOf(child), 1);
    body.splice(body.indexOf(child.node), 1);
  }
  commitMount() {
    return void 0;
  }
  commitUpdate(newProps) {
    this.props = {
      ...this.props,
      ...newProps
    };
  }
  getProps(props) {
    props = { ...props };
    const { defaultProps, propTypes } = this.constructor;
    Object.keys(defaultProps).forEach((key) => {
      const defaultProp = defaultProps[key];
      if (typeof props[key] === "undefined" || props[key] === null) {
        props[key] = defaultProp;
      }
    });
    PropTypes.checkPropTypes(propTypes, props, "prop", this.constructor.name);
    return props;
  }
};
BaseElement.defaultProps = {};
BaseElement.propTypes = {};

export {
  BaseElement
};
