import {
  ClassMethod_default,
  ClassProperty_default,
  Class_default,
  TypeParameterInstantiation_default,
  TypeReference_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/classes/Class/index.spec.tsx
import React from "react";
describe("<Class />", () => {
  it("renders", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(Class_default, { name: "Hello", debug: true }), {
      prettier: false
    });
    expect(code).toBe("class Hello {}");
  });
  it("renders with type parameters", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Class_default,
        {
          name: "Hello",
          typeParameters: ["A", /* @__PURE__ */ React.createElement(TypeReference_default, { key: 0, name: "B" })],
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("class Hello<A, B> {}");
  });
  it("renders with type parameters as string", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(Class_default, { name: "Hello", typeParameters: "T", debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("class Hello<T> {}");
  });
  it("renders with nested type parameters", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Class_default,
        {
          name: "Hello",
          typeParameters: /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" }))),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("class Hello<T<A, B>> {}");
  });
  it("renders with super class", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Class_default,
        {
          name: "Hello",
          typeParameters: /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" }))),
          extends: "Howdy",
          extendsTypeParameters: /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "C" }))),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("class Hello<T<A, B>> extends Howdy<A<B, C>> {}");
  });
  it("renders with class properties", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Class_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(
        ClassProperty_default,
        {
          name: "hello",
          typeAnnotation: "T",
          accessibility: "protected" /* Protected */
        },
        "world"
      )),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`class Hello {
  protected hello: T = "world";
}`);
  });
  it("renders with class methods", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Class_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(
        ClassMethod_default,
        {
          name: "hello",
          returnType: "T",
          accessibility: "protected" /* Protected */
        }
      )),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`class Hello {
  protected hello(): T {}
}`);
  });
  it("renders with class properties and methods", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Class_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(
        ClassProperty_default,
        {
          name: "hello",
          typeAnnotation: "T",
          accessibility: "protected" /* Protected */
        },
        "world"
      ), /* @__PURE__ */ React.createElement(
        ClassMethod_default,
        {
          name: "hello",
          returnType: "T",
          accessibility: "protected" /* Protected */
        }
      )),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`class Hello {
  protected hello: T = "world";
  protected hello(): T {}
}`);
  });
});
