import {
  ClassMethod_default,
  Identifier_default,
  TypeAnnotation_default,
  TypeParameterInstantiation_default,
  TypeReference_default,
  VariableDeclaration_default,
  VariableDeclarator_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/classes/ClassMethod/index.spec.tsx
import React from "react";
describe("<ClassMethod />", () => {
  it("renders empty method", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(ClassMethod_default, { name: "hello", debug: true }), {
      prettier: false
    });
    expect(code).toBe("hello() {}");
  });
  it("renders with static", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(ClassMethod_default, { static: true, name: "hello", debug: true }), {
      prettier: false
    });
    expect(code).toBe("static hello() {}");
  });
  it("renders with accessibility", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassMethod_default,
        {
          name: "hello",
          accessibility: "private" /* Private */,
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("private hello() {}");
  });
  it("renders with static accessibility", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassMethod_default,
        {
          static: true,
          accessibility: "private" /* Private */,
          name: "hello",
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("private static hello() {}");
  });
  it("renders with nested return type", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassMethod_default,
        {
          name: "hello",
          returnType: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" })))),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("hello(): T<A, B> {}");
  });
  it("renders with return type as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassMethod_default, { name: "hello", returnType: "T<A, B, C>", debug: true }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("hello(): T<A, B, C> {}");
  });
  it("renders with nested children", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassMethod_default, { name: "hello", debug: true }, /* @__PURE__ */ React.createElement(VariableDeclaration_default, { debug: true }, /* @__PURE__ */ React.createElement(
        VariableDeclarator_default,
        {
          name: "v",
          typeAnnotation: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, "T"),
          debug: true
        },
        "hello"
      ))),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`hello() {
  var v: T = "hello";
}`);
  });
  it("renders with params as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassMethod_default, { name: "hello", params: ["a", "b", "c"], debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("hello(a, b, c) {}");
  });
  it("renders with children as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassMethod_default, { name: "hello", debug: true }, "const hello = 0;"),
      {
        prettier: false
      }
    );
    expect(code).toBe(`hello() {
  const hello = 0;
}`);
  });
  it("renders with typed params", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassMethod_default,
        {
          name: "hello",
          params: [
            /* @__PURE__ */ React.createElement(Identifier_default, { key: "a", typeAnnotation: "A" }, "a"),
            /* @__PURE__ */ React.createElement(Identifier_default, { key: "b", typeAnnotation: "T<A, B>" }, "b"),
            /* @__PURE__ */ React.createElement(
              Identifier_default,
              {
                key: "c",
                typeAnnotation: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "C" }))))
              },
              "c"
            )
          ],
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("hello(a: A, b: T<A, B>, c: T<A, B, C>) {}");
  });
  it("renders with all props", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassMethod_default,
        {
          returnType: "T<A, B>",
          params: [
            /* @__PURE__ */ React.createElement(Identifier_default, { key: "a", typeAnnotation: "A" }, "a"),
            /* @__PURE__ */ React.createElement(Identifier_default, { key: "b", typeAnnotation: "B" }, "b")
          ],
          name: "hello",
          debug: true
        },
        /* @__PURE__ */ React.createElement(VariableDeclaration_default, { debug: true }, /* @__PURE__ */ React.createElement(
          VariableDeclarator_default,
          {
            name: "v",
            typeAnnotation: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, "T"),
            debug: true
          },
          "hello"
        ))
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`hello(a: A, b: B): T<A, B> {
  var v: T = "hello";
}`);
  });
});
