import {
  ClassProperty_default,
  TypeAnnotation_default,
  TypeParameterInstantiation_default,
  TypeReference_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/classes/ClassProperty/index.spec.tsx
import React from "react";
describe("<ClassProperty />", () => {
  it("renders", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(ClassProperty_default, { name: "p", debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("p;");
  });
  it("renders with static", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(ClassProperty_default, { static: true, name: "p", debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("static p;");
  });
  it("renders with accessibility", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassProperty_default,
        {
          name: "p",
          accessibility: "private" /* Private */,
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("private p;");
  });
  it("renders with static accessibility", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassProperty_default,
        {
          accessibility: "private" /* Private */,
          static: true,
          name: "p",
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("private static p;");
  });
  it("renders with type annotation", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassProperty_default,
        {
          name: "p",
          typeAnnotation: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, "T"),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("p: T;");
  });
  it("renders with nested type annotation", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ClassProperty_default,
        {
          name: "p",
          typeAnnotation: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" })))),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("p: T<A, B>;");
  });
  it("renders with annotation as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassProperty_default, { name: "p", typeAnnotation: "T<A>", debug: true }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("p: T<A>;");
  });
  it("renders with initial value as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassProperty_default, { name: "p", typeAnnotation: "T<A>", debug: true }, "hello"),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe('p: T<A> = "hello";');
  });
  it("renders with initial value as boolean", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassProperty_default, { name: "p", typeAnnotation: "T<A>", debug: true }, true),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("p: T<A> = true;");
  });
  it("renders with initial value as number", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassProperty_default, { name: "p", typeAnnotation: "T<A>", debug: true }, 0),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("p: T<A> = 0;");
  });
  it("renders with initial value as object", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ClassProperty_default, { name: "p", typeAnnotation: "T<A>", debug: true }, { hello: "world" }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`p: T<A> = {
  "hello": "world"
};`);
  });
});
