import {
  ArrowFunctionExpression_default,
  Expression_default,
  Identifier_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/expressions/Expression/index.spec.tsx
import React from "react";
describe("<Expression />", () => {
  it("renders expression with properties", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: ["hello", "world", "howdy"], debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("hello.world.howdy");
  });
  it("renders expression with properties as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "howdy.hello.world", debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("howdy.hello.world");
  });
  it("renders expression with property as string", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(Expression_default, { identifiers: "howdy", debug: true }), {
      prettier: false
    });
    expect(code).toBe("howdy");
  });
  it("renders called expression with property as string", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(Expression_default, { identifiers: "hello", call: true, debug: true }), {
      prettier: false
    });
    expect(code).toBe("hello()");
  });
  it("renders called expression with properties", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: ["hello", "world"], call: true, debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("hello.world()");
  });
  it("renders called expression with properties as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "howdy.texas", call: true, debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("howdy.texas()");
  });
  it("renders called expression with properties and argument", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Expression_default,
        {
          identifiers: "hello.world",
          arguments: /* @__PURE__ */ React.createElement(Identifier_default, null, "a"),
          call: true,
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("hello.world(a)");
  });
  it("renders called expression with properties and arguments", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Expression_default,
        {
          identifiers: ["hello", "world"],
          arguments: [
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 0 }, "a"),
            /* @__PURE__ */ React.createElement(ArrowFunctionExpression_default, { key: 1 })
          ],
          call: true,
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("hello.world(a, () => {})");
  });
  it("renders called expression with properties and argument as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "howdy.texas", arguments: "a", call: true, debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("howdy.texas(a)");
  });
  it("renders called expression with properties and arguments as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Expression_default,
        {
          identifiers: ["howdy", "texas"],
          arguments: ["a", "b", "c"],
          call: true,
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("howdy.texas(a, b, c)");
  });
  it("renders assigning no children", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(Expression_default, { identifiers: "a.b.c", debug: true }), {
      prettier: false
    });
    expect(code).toBe("a.b.c");
  });
  it("renders assigning initial value as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "a.b.c", debug: true }, "hello"),
      {
        prettier: false
      }
    );
    expect(code).toBe('a.b.c = "hello"');
  });
  it("renders assigning initial value as boolean", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "a.b.c", debug: true }, true),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("a.b.c = true");
  });
  it("renders assigning initial value as number", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "a.b.c", debug: true }, 0),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("a.b.c = 0");
  });
  it("renders assigning initial value as object", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "a.b.c", debug: true }, { hello: "world" }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`a.b.c = {
  "hello": "world"
}`);
  });
  it("renders assigning initial value as component", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Expression_default, { identifiers: "a.b.c", debug: true }, /* @__PURE__ */ React.createElement(ArrowFunctionExpression_default, null)),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("a.b.c = () => {}");
  });
});
