import {
  ArrayExpression_default,
  Interface_default,
  MethodSignature_default,
  PropertySignature_default,
  TypeAnnotation_default,
  TypeParameterInstantiation_default,
  TypeReference_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/interfaces/Interface/index.spec.tsx
import React from "react";
describe("<Interface />", () => {
  it("r", async () => {
    const arr = ["GTK.Widget", "any", "GLib.DestroyNotify"];
    const code = await render(
      /* @__PURE__ */ React.createElement(Interface_default, { name: "I" }, /* @__PURE__ */ React.createElement(
        PropertySignature_default,
        {
          name: "a",
          typeAnnotation: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, /* @__PURE__ */ React.createElement(ArrayExpression_default, null, arr.map((item, index) => /* @__PURE__ */ React.createElement(TypeReference_default, { key: index, name: item }))))
        }
      )),
      {
        prettier: false
      }
    );
    expect(code).toBe(`interface I {
  a: [GTK.Widget, any, GLib.DestroyNotify];
}`);
  });
  it("renders", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(Interface_default, { name: "Hello", debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("interface Hello {}");
  });
  it("renders with type parameters", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Interface_default,
        {
          name: "Hello",
          typeParameters: ["A", /* @__PURE__ */ React.createElement(TypeReference_default, { key: "B", name: "B" })],
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface Hello<A, B> {}");
  });
  it("renders with type parameters as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Interface_default, { name: "Hello", typeParameters: "T", debug: true }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface Hello<T> {}");
  });
  it("renders with nested type parameters", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        Interface_default,
        {
          name: "Hello",
          typeParameters: /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" }))),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface Hello<T<A, B>> {}");
  });
  it("renders with interface property signatures", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Interface_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(PropertySignature_default, { name: "hello", typeAnnotation: "T" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`interface Hello {
  hello: T;
}`);
  });
  it("renders with interface method signatures", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Interface_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(MethodSignature_default, { name: "hello", returnType: "T" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`interface Hello {
  hello(): T;
}`);
  });
  it("renders with interface method and property signatures", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(Interface_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(PropertySignature_default, { name: "hello", typeAnnotation: "T" }), /* @__PURE__ */ React.createElement(PropertySignature_default, { name: "world", optional: true, typeAnnotation: "T" }), /* @__PURE__ */ React.createElement(MethodSignature_default, { name: "foo", returnType: "T" }), /* @__PURE__ */ React.createElement(MethodSignature_default, { name: "bar", optional: true, returnType: "T" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`interface Hello {
  hello: T;
  world?: T;
  foo(): T;
  bar?(): T;
}`);
  });
});
