import {
  ExpressionWithTypeArguments_default,
  Identifier_default,
  InterfaceDeclaration_default,
  InterfaceTypeReference_default,
  MethodSignature_default,
  PropertySignature_default,
  TypeParameterInstantiation_default,
  TypeReference_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/interfaces/InterfaceDeclaration/index.spec.tsx
import React from "react";
describe("<InterfaceDeclaration />", () => {
  it("renders", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(InterfaceDeclaration_default, { name: "Hello", debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("interface Hello {}");
  });
  it("renders", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        InterfaceDeclaration_default,
        {
          extends: [
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 0 }, "Hello"),
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 1 }, "Ok")
          ],
          name: "Hello",
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface Hello extends Hello, Ok {}");
  });
  it("renders with type parameters", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        InterfaceDeclaration_default,
        {
          name: "Hello",
          typeParameters: ["A", /* @__PURE__ */ React.createElement(TypeReference_default, { key: "B", name: "B" })],
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface Hello<A, B> {}");
  });
  it("renders with type parameters as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(InterfaceDeclaration_default, { name: "Hello", typeParameters: "T", debug: true }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface Hello<T> {}");
  });
  it("renders with type arguments", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        InterfaceDeclaration_default,
        {
          name: "A",
          extends: [
            /* @__PURE__ */ React.createElement(ExpressionWithTypeArguments_default, { key: 0, name: "B" }, /* @__PURE__ */ React.createElement(InterfaceTypeReference_default, null, "C"), /* @__PURE__ */ React.createElement(InterfaceTypeReference_default, null, "D")),
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 2 }, "E")
          ],
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface A extends B<C, D>, E {}");
  });
  it("renders with nested type parameters", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        InterfaceDeclaration_default,
        {
          name: "Hello",
          typeParameters: /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" }))),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("interface Hello<T<A, B>> {}");
  });
  it("renders with interface property signatures", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(InterfaceDeclaration_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(PropertySignature_default, { name: "hello", typeAnnotation: "T" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`interface Hello {
  hello: T;
}`);
  });
  it("renders with interface method signatures", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(InterfaceDeclaration_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(MethodSignature_default, { name: "hello", returnType: "T" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`interface Hello {
  hello(): T;
}`);
  });
  it("renders with interface method and property signatures", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(InterfaceDeclaration_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(PropertySignature_default, { name: "hello", typeAnnotation: "T" }), /* @__PURE__ */ React.createElement(MethodSignature_default, { name: "hello", returnType: "T" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(`interface Hello {
  hello: T;
  hello(): T;
}`);
  });
});
