import {
  Identifier_default,
  MethodSignature_default,
  TypeAnnotation_default,
  TypeParameterInstantiation_default,
  TypeReference_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/interfaces/MethodSignature/index.spec.tsx
import React from "react";
describe("<MethodSignature />", () => {
  it("renders empty method signature", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(MethodSignature_default, { name: "hello", debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("hello(): any;");
  });
  it("renders with nested return type", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        MethodSignature_default,
        {
          name: "hello",
          returnType: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" })))),
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("hello(): T<A, B>;");
  });
  it("renders with return type as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(MethodSignature_default, { name: "hello", returnType: "T<A, B, C>", debug: true }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("hello(): T<A, B, C>;");
  });
  it("renders with params as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(MethodSignature_default, { name: "hello", params: ["a", "b", "c"], debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("hello(a, b, c): any;");
  });
  it("renders with typed params", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        MethodSignature_default,
        {
          name: "hello",
          params: [
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 0, typeAnnotation: "A" }, "a"),
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 1, typeAnnotation: "T<A, B>" }, "b"),
            /* @__PURE__ */ React.createElement(
              Identifier_default,
              {
                key: 2,
                typeAnnotation: /* @__PURE__ */ React.createElement(TypeAnnotation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "T" }, /* @__PURE__ */ React.createElement(TypeParameterInstantiation_default, null, /* @__PURE__ */ React.createElement(TypeReference_default, { name: "A" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "B" }), /* @__PURE__ */ React.createElement(TypeReference_default, { name: "C" }))))
              },
              "c"
            )
          ],
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("hello(a: A, b: T<A, B>, c: T<A, B, C>): any;");
  });
  it("renders with all props", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        MethodSignature_default,
        {
          returnType: "T<A, B>",
          params: [
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 0, typeAnnotation: "A" }, "a"),
            /* @__PURE__ */ React.createElement(Identifier_default, { key: 1, typeAnnotation: "B" }, "b")
          ],
          name: "hello",
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("hello(a: A, b: B): T<A, B>;");
  });
});
