import {
  ArrowFunctionExpression_default,
  Identifier_default,
  JsxElement_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/jsx/JsxElement/index.spec.tsx
import React from "react";
describe("<JsxElement />", () => {
  it("renders jsx element", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(JsxElement_default, { name: "Hello", debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("<Hello />");
  });
  it("renders jsx element with no name", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(JsxElement_default, { debug: true }), {
      prettier: false,
      parserOptions: {
        plugins: ["jsx", "classProperties", "typescript"]
      }
    });
    expect(code).toBe("<></>");
  });
  it("force no self closing", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(JsxElement_default, { name: "Hello", selfClosing: false, debug: true }),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("<Hello></Hello>");
  });
  it("renders jsx no name with children", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(JsxElement_default, { debug: true }, /* @__PURE__ */ React.createElement(JsxElement_default, { name: "World" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("<><World /></>");
  });
  it("renders jsx element with children", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(JsxElement_default, { name: "Hello", debug: true }, /* @__PURE__ */ React.createElement(JsxElement_default, { name: "World" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("<Hello><World /></Hello>");
  });
  it("disable force self closing with children", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(JsxElement_default, { name: "Hello", selfClosing: true, debug: true }, /* @__PURE__ */ React.createElement(JsxElement_default, { name: "World" })),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe("<Hello><World /></Hello>");
  });
  it("renders jsx element with attributes", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        JsxElement_default,
        {
          name: "Hello",
          attributes: {
            a: /* @__PURE__ */ React.createElement(Identifier_default, null, "a"),
            b: "b",
            c: true,
            d: /* @__PURE__ */ React.createElement(ArrowFunctionExpression_default, null)
          },
          debug: true
        }
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe('<Hello a={a} b="b" c d={() => {}} />');
  });
  it("renders jsx element with attributes and children", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        JsxElement_default,
        {
          name: "Hello",
          attributes: {
            a: /* @__PURE__ */ React.createElement(Identifier_default, null, "a"),
            b: "b",
            c: true,
            d: /* @__PURE__ */ React.createElement(ArrowFunctionExpression_default, null)
          },
          debug: true
        },
        /* @__PURE__ */ React.createElement(
          JsxElement_default,
          {
            name: "World",
            attributes: {
              a: /* @__PURE__ */ React.createElement(Identifier_default, null, "a"),
              b: "b",
              c: true,
              d: /* @__PURE__ */ React.createElement(ArrowFunctionExpression_default, null)
            },
            debug: true
          }
        )
      ),
      {
        prettier: false,
        parserOptions: {
          plugins: ["jsx", "classProperties", "typescript"]
        }
      }
    );
    expect(code).toBe(
      '<Hello a={a} b="b" c d={() => {}}><World a={a} b="b" c d={() => {}} /></Hello>'
    );
  });
});
