import {
  ArrowFunctionExpression_default,
  ExportNamedDeclaration_default,
  ExportSpecifier_default,
  VariableDeclaration_default,
  VariableDeclarator_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/modules/ExportNamedDeclaration/index.spec.tsx
import React from "react";
describe("<ExportNamedDeclaration />", () => {
  it("renders empty named declaration", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(ExportNamedDeclaration_default, { debug: true }), {
      prettier: false
    });
    expect(code).toBe("export {};");
  });
  it("renders with specifier", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ExportNamedDeclaration_default,
        {
          specifiers: /* @__PURE__ */ React.createElement(ExportSpecifier_default, null, "hello"),
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("export { hello };");
  });
  it("renders with specifiers", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ExportNamedDeclaration_default,
        {
          specifiers: [
            /* @__PURE__ */ React.createElement(ExportSpecifier_default, { key: "hello" }, "hello"),
            /* @__PURE__ */ React.createElement(ExportSpecifier_default, { key: "world" }, "world")
          ],
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("export { hello, world };");
  });
  it("renders with specifier as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ExportNamedDeclaration_default, { specifiers: "hello", debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("export { hello };");
  });
  it("renders with specifiers as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ExportNamedDeclaration_default, { specifiers: ["hello", "world"], debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("export { hello, world };");
  });
  it("renders with specifiers and source", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ExportNamedDeclaration_default,
        {
          specifiers: ["hello", "world"],
          source: "./world",
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("export { hello, world } from './world';");
  });
  it("renders with source", async () => {
    const code = await render(/* @__PURE__ */ React.createElement(ExportNamedDeclaration_default, { source: "world", debug: true }), {
      prettier: false
    });
    expect(code).toBe("export {} from 'world';");
  });
  it("renders with children", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ExportNamedDeclaration_default, { debug: true }, /* @__PURE__ */ React.createElement(VariableDeclaration_default, null, /* @__PURE__ */ React.createElement(VariableDeclarator_default, { name: "hello" }, /* @__PURE__ */ React.createElement(ArrowFunctionExpression_default, null)))),
      {
        prettier: false
      }
    );
    expect(code).toBe("export var hello = () => {};");
  });
  it("renders the export kind type", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ExportNamedDeclaration_default,
        {
          exportKind: "type",
          specifiers: [
            /* @__PURE__ */ React.createElement(ExportSpecifier_default, { key: "hello" }, "hello"),
            /* @__PURE__ */ React.createElement(ExportSpecifier_default, { key: "ok" }, "ok")
          ],
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("export type { hello, ok };");
  });
});
