import {
  ImportDeclaration_default,
  ImportSpecifier_default
} from "../../../chunk-46FLVA3G.mjs";
import "../../../chunk-GLDVX3MD.mjs";
import "../../../chunk-SBY46IGC.mjs";
import "../../../chunk-U3PXES67.mjs";
import {
  render
} from "../../../chunk-7KBPBLKV.mjs";
import "../../../chunk-TO7OBY6Q.mjs";
import "../../../chunk-3QLF7IWK.mjs";
import "../../../chunk-AMII3PHO.mjs";
import "../../../chunk-OOWEXA44.mjs";
import "../../../chunk-ZXXMYMGZ.mjs";
import "../../../chunk-NQZS4VCS.mjs";
import "../../../chunk-YZ4M5FIM.mjs";
import "../../../chunk-BWVOPACC.mjs";
import "../../../chunk-F5OTY3X7.mjs";
import "../../../chunk-QCSCUMAH.mjs";
import "../../../chunk-WBQAMGXK.mjs";
import "../../../chunk-BBDMJ3VH.mjs";

// src/components/modules/ImportDeclaration/index.spec.tsx
import React from "react";
describe("<ImportDeclaration />", () => {
  it("renders with default specifier", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ImportDeclaration_default, { defaultSpecifier: "hello", source: "world", debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("import hello from 'world';");
  });
  it("renders with namespace specifier", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ImportDeclaration_default, { namespaceSpecifier: "hello", source: "world", debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("import * as hello from 'world';");
  });
  it("renders with namespace specifier override", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ImportDeclaration_default,
        {
          namespaceSpecifier: "hello",
          defaultSpecifier: "hello",
          specifiers: "hello",
          source: "world",
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("import * as hello from 'world';");
  });
  it("renders with specifier", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(ImportDeclaration_default, { specifiers: "hello", source: "world", debug: true }),
      {
        prettier: false
      }
    );
    expect(code).toBe("import { hello } from 'world';");
  });
  it("renders with specifiers", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ImportDeclaration_default,
        {
          specifiers: [
            /* @__PURE__ */ React.createElement(ImportSpecifier_default, { key: "hello" }, "hello"),
            /* @__PURE__ */ React.createElement(ImportSpecifier_default, { key: "howdy" }, "howdy")
          ],
          source: "world",
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("import { hello, howdy } from 'world';");
  });
  it("renders with specifiers as string", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ImportDeclaration_default,
        {
          specifiers: ["hello", "howdy"],
          source: "world",
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("import { hello, howdy } from 'world';");
  });
  it("renders with specifiers and default specifier", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ImportDeclaration_default,
        {
          defaultSpecifier: "hello",
          specifiers: [/* @__PURE__ */ React.createElement(ImportSpecifier_default, { key: "howdy" }, "howdy")],
          source: "world",
          debug: true
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("import hello, { howdy } from 'world';");
  });
  it("renders import type", async () => {
    const code = await render(
      /* @__PURE__ */ React.createElement(
        ImportDeclaration_default,
        {
          importKind: "type",
          specifiers: ["hello", "howdy"],
          source: "world"
        }
      ),
      {
        prettier: false
      }
    );
    expect(code).toBe("import type { hello, howdy } from 'world';");
  });
});
